@@ -36,4 +36,4 @@ def write_notebook(nb: Notebook, filepath: Union[str, Path]):
     with open(filepath, "wb") as f:
         # the formatting orjson dumps doesn't match jupyter lab
         # maybe one can homogenize it at some point
-        f.write(orjson.dumps(nb.dict()))
+        f.write(orjson.dumps(nb.dict(), option=orjson.OPT_INDENT_2))
